# Generated by Django 3.1.3 on 2021-02-03 17:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0002_auto_20191218_0625"),
    ]

    operations = [
        migrations.AlterField(
            model_name="accountkituser",
            name="me",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="facebookuser",
            name="me",
            field=models.JSONField(blank=True, default=dict),
        ),
        migrations.AlterField(
            model_name="googleuser",
            name="me",
            field=models.JSONField(blank=True, default=dict),
        ),
    ]



# Generated by Django 4.0.3 on 2022-03-27 01:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0003_auto_20210203_1718"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="accountkituser",
            name="user",
        ),
        migrations.DeleteModel(
            name="AccountKitAccessToken",
        ),
        migrations.DeleteModel(
            name="AccountKitUser",
        ),
    ]



# Generated by Django 4.0.4 on 2024-10-14 19:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0005_alter_facebookaccesstoken_access_token_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="facebookuser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=256),
        ),
        migrations.AlterField(
            model_name="googleuser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=256),
        ),
    ]



# Generated by Django 4.0.4 on 2024-10-14 19:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0004_remove_accountkituser_user_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="facebookaccesstoken",
            name="access_token",
            field=models.CharField(max_length=2048),
        ),
        migrations.AlterField(
            model_name="googleaccesstoken",
            name="access_token",
            field=models.CharField(max_length=2048),
        ),
    ]



# Generated by Django 2.2.3 on 2019-12-18 06:25

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ("jauth", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="accountkituser",
            name="created",
            field=models.DateTimeField(blank=True, db_index=True, default=django.utils.timezone.now, editable=False, verbose_name="created"),
        ),
        migrations.AddField(
            model_name="facebookuser",
            name="created",
            field=models.DateTimeField(blank=True, db_index=True, default=django.utils.timezone.now, editable=False, verbose_name="created"),
        ),
        migrations.AddField(
            model_name="googleuser",
            name="created",
            field=models.DateTimeField(blank=True, db_index=True, default=django.utils.timezone.now, editable=False, verbose_name="created"),
        ),
        migrations.AlterField(
            model_name="accountkituser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="facebookuser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=32),
        ),
        migrations.AlterField(
            model_name="googleuser",
            name="ext_user_id",
            field=models.CharField(db_index=True, max_length=32),
        ),
    ]



# Generated by Django 2.2.3 on 2019-07-15 17:13

from django.conf import settings
import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="GoogleUser",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("ext_user_id", models.CharField(db_index=True, max_length=32, unique=True)),
                ("me", django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict)),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="GoogleAccessToken",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("access_token", models.CharField(max_length=255)),
                ("expire_time", models.DateTimeField(db_index=True)),
                (
                    "ext_user",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="+", to="jauth.GoogleUser"),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="FacebookUser",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("ext_user_id", models.CharField(db_index=True, max_length=32, unique=True)),
                ("me", django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict)),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="FacebookAccessToken",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("access_token", models.CharField(max_length=255)),
                ("expire_time", models.DateTimeField(db_index=True)),
                (
                    "ext_user",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="+", to="jauth.FacebookUser"),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="AccountKitUser",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("ext_user_id", models.CharField(db_index=True, max_length=32, unique=True)),
                ("me", django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict)),
                (
                    "user",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
        migrations.CreateModel(
            name="AccountKitAccessToken",
            fields=[
                ("id", models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                ("access_token", models.CharField(max_length=255)),
                ("expire_time", models.DateTimeField(db_index=True)),
                (
                    "ext_user",
                    models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name="+", to="jauth.AccountKitUser"),
                ),
            ],
            options={
                "abstract": False,
            },
        ),
    ]
